@@ -4,11 +4,12 @@
 from unittest.case import TestCase
 
 from core_curate_registry_app.utils import jquery
-from core_parser_app.components.data_structure_element.models import DataStructureElement
+from core_parser_app.components.data_structure_element.models import (
+    DataStructureElement,
+)
 
 
 class TestUtilsGetJqueryFromDataStructureElement(TestCase):
-
     def test_utils_get_jquery_from_data_structure_element_returns_data(self):
         # Arrange
         string_expected = ".element1,.element2,.element3"
@@ -34,9 +35,8 @@ class TestUtilsGetJqueryFromDataStructureElement(TestCase):
         # Arrange
         object1 = "element1"
         string_expected = ".element1"
-        data_list =[object1]
+        data_list = [object1]
         # Act
         result = jquery.get_jquery_selector_from_data_structure(data_list)
         # Assert
         self.assertEqual(string_expected, result)
-
